==> haskell-dependent-sum-0.7.2.0-206-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dependent-sum
version:              0.7.2.0
visibility:           public
id:                   dependent-sum-0.7.2.0-8GyWrxBL8PLKZtrboWFsHt
key:                  dependent-sum-0.7.2.0-8GyWrxBL8PLKZtrboWFsHt
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:             Dependent sum type
description:
    A dependent sum is a generalization of a
    particular way of thinking about the @Either@
    type.  @Either a b@ can be thought of as a
    2-tuple @(tag, value)@, where the value of the
    tag determines the type of the value.  In
    particular, either @tag = Left@ and @value :: a@
    or @tag = Right@ and @value :: b@.

    This package allows you to define your own
    dependent sum types by using your own \"tag\"
    types.

category:             Data, Dependent Types
abi:                  65601f1b78eba468dc86f13d7baf4c68
exposed:              True
exposed-modules:
    Data.Dependent.Sum,
    Data.GADT.Compare from some-1.0.6-IiRblKvQPLw6GFNXPDbNXz:Data.GADT.Compare,
    Data.GADT.Show from some-1.0.6-IiRblKvQPLw6GFNXPDbNXz:Data.GADT.Show,
    Data.Some from some-1.0.6-IiRblKvQPLw6GFNXPDbNXz:Data.Some

import-dirs:          /usr/lib/ghc-9.4.8/site-local/dependent-sum-0.7.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dependent-sum-0.7.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dependent-sum-0.7.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum
hs-libraries:         HSdependent-sum-0.7.2.0-8GyWrxBL8PLKZtrboWFsHt
depends:
    base-4.17.2.1 constraints-extras-0.4.0.2-9ngKIKlfy64V7ePYqRIO3
    some-1.0.6-IiRblKvQPLw6GFNXPDbNXz

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum/html/dependent-sum.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dependent-sum-0.7.2.0-207-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dependent-sum
version:              0.7.2.0
visibility:           public
id:                   dependent-sum-0.7.2.0-1saMXReLF1qGmyvwnMahh6
key:                  dependent-sum-0.7.2.0-1saMXReLF1qGmyvwnMahh6
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:             Dependent sum type
description:
    A dependent sum is a generalization of a
    particular way of thinking about the @Either@
    type.  @Either a b@ can be thought of as a
    2-tuple @(tag, value)@, where the value of the
    tag determines the type of the value.  In
    particular, either @tag = Left@ and @value :: a@
    or @tag = Right@ and @value :: b@.

    This package allows you to define your own
    dependent sum types by using your own \"tag\"
    types.

category:             Data, Dependent Types
abi:                  219affa7219ff44024a61c7b0f5107a5
exposed:              True
exposed-modules:
    Data.Dependent.Sum,
    Data.GADT.Compare from some-1.0.6-KVr2xKoodpQEz21w3ZX7aM:Data.GADT.Compare,
    Data.GADT.Show from some-1.0.6-KVr2xKoodpQEz21w3ZX7aM:Data.GADT.Show,
    Data.Some from some-1.0.6-KVr2xKoodpQEz21w3ZX7aM:Data.Some

import-dirs:          /usr/lib/ghc-9.4.8/site-local/dependent-sum-0.7.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dependent-sum-0.7.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dependent-sum-0.7.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum
hs-libraries:         HSdependent-sum-0.7.2.0-1saMXReLF1qGmyvwnMahh6
depends:
    base-4.17.2.1 constraints-extras-0.4.0.2-EWWbAAeJU73KGHQo8l0Bbf
    some-1.0.6-KVr2xKoodpQEz21w3ZX7aM

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum/html/dependent-sum.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
